//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[HoraArgsValidationException](index.md)

# HoraArgsValidationException

[common]\
class [HoraArgsValidationException](index.md)(val args: [HoraArgs](../-hora-args/index.md), val errors: [Collection](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-collection/index.html)&lt;[HoraArgsErrorInfo](../-hora-args-error-info/index.md)&gt;) : [ValidationException](../../mahjongutils/-validation-exception/index.md)

## Constructors

| | |
|---|---|
| [HoraArgsValidationException](-hora-args-validation-exception.md) | [common]<br>constructor(args: [HoraArgs](../-hora-args/index.md), errors: [Collection](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-collection/index.html)&lt;[HoraArgsErrorInfo](../-hora-args-error-info/index.md)&gt;) |

## Properties

| Name | Summary |
|---|---|
| [args](args.md) | [common]<br>val [args](args.md): [HoraArgs](../-hora-args/index.md) |
| [cause](../../mahjongutils.shanten/-furo-chance-shanten-args-validation-exception/index.md#-654012527%2FProperties%2F1581026887) | [common]<br>open val [cause](../../mahjongutils.shanten/-furo-chance-shanten-args-validation-exception/index.md#-654012527%2FProperties%2F1581026887): [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html)? |
| [errors](../../mahjongutils/-validation-exception/errors.md) | [common]<br>val [errors](../../mahjongutils/-validation-exception/errors.md): [Collection](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-collection/index.html)&lt;[ErrorInfo](../../mahjongutils/-error-info/index.md)&gt; |
| [message](../../mahjongutils/-validation-exception/message.md) | [common]<br>open override val [message](../../mahjongutils/-validation-exception/message.md): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
